@@ -33,8 +33,8 @@
 
 #include <cpl.h>
 #include "casu_mods.h"
-#include "casu_utils.h"
-#include "casu_fits.h"
+#include "catalogue/casu_utils.h"
+#include "catalogue/casu_fits.h"
 #include "casu_stats.h"
 
 #include <stdio.h>
